gender_dict = {
    'Aaron': 'male',
    'Abigail': 'female',
    'Adam': 'male',
    'Aiden': 'male',
    'Alice': 'female',
    'Amanda': 'female',
    'Andrew': 'male',
    'Angela': 'female',
    'Ashley': 'female',
    'Austin': 'male',
    'Benjamin': 'male',
    'Brianna': 'female',
    'Cameron': 'unisex',
    'Charles': 'male',
    'Charlotte': 'female',
    'Chloe': 'female',
    'Daniel': 'male',
    'David': 'male',
    'Emma': 'female',
    'Ethan': 'male',
    'Grace': 'female',
    'Hannah': 'female',
    'Isabella': 'female',
    'James': 'male',
    'Jessica': 'female',
    'John': 'male',
    'Julia': 'female',
    'Liam': 'male',
    'Linda': 'female',
    'Lucas': 'male',
    'Mason': 'male',
    'Mia': 'female',
    'Michael': 'male',
    'Natalie': 'female',
    'Noah': 'male',
    'Oliver': 'male',
    'Olivia': 'female',
    'Robert': 'male',
    'Samantha': 'female',
    'Sarah': 'female',
    'Sophia': 'female',
    'Taylor': 'unisex',
    'Victoria': 'female',
    'William': 'male',
    'Zoe': 'female',
    'Avery': 'unisex',
    'Jordan': 'unisex',
    'Riley': 'unisex',
    'Casey': 'unisex',
    'Peyton': 'unisex',
    'Sydney': 'unisex',
    'Dakota': 'unisex',
    'Elijah': 'male',
    'Gabriel': 'male',
    'Grace': 'female',
    'Hazel': 'female',
    'Jack': 'male',
    'Jasmine': 'female',
    'Lily': 'female',
    'Lucas': 'male',
    'Maya': 'female',
    'Nina': 'female',
    'Oliver': 'male',
    'Penelope': 'female',
    'Quinn': 'unisex',
    'Samuel': 'male',
    'Sofia': 'female',
    'Toby': 'male',
    'Violet': 'female',
    'Xander': 'male',
    'Yara': 'female',
    'Zane': 'male',
    'Aaliyah': 'female',
    'Bianca': 'female',
    'Cecilia': 'female',
    'Dante': 'male',
    'Evelyn': 'female',
    'Freddie': 'male',
    'Giselle': 'female',
    'Hugo': 'male',
    'Ivy': 'female',
    'Jasper': 'male',
    'Kinsley': 'female',
    'Leo': 'male',
    'Maddox': 'male',
    'Nora': 'female',
    'Owen': 'male',
    'Paige': 'female',
    'Quincy': 'male',
    'Raven': 'unisex',
    'Silas': 'male',
    'Tessa': 'female',
    'Uriah': 'male',
    'Vera': 'female',
    'Willa': 'female',
    'Ximena': 'female',
    'Yasmine': 'female',
    'Zuri': 'female',
    # Daha fazla isim eklenebilir
}

def get_gender(entities):
    genders = {}
    for entity in entities:
        if entity in gender_dict:
            genders[entity] = gender_dict[entity]
    return genders
